
# Slot: start_activities

The set of activities that are the starting points of the model, i.e. those that have no incoming causal associations.

URI: [gocam:queryIndex__start_activities](https://w3id.org/gocam/queryIndex__start_activities)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Activity](Activity.md)

## Parents


## Children


## Used by

 * [QueryIndex](QueryIndex.md)
